@@ -58,7 +58,7 @@ class DownloadBase(object):
         self.end = end
         if headers is None:
             headers = {}
-        self._headers = _helpers._base_headers(headers)
+        self._headers = headers
         self._finished = False
         self._retry_strategy = common.RetryStrategy()
 
