@@ -20,7 +20,6 @@ import base64
 import hashlib
 import logging
 import random
-import pkg_resources
 import warnings
 
 from google.resumable_media import common
@@ -46,13 +45,6 @@ def do_nothing():
     """Simple default callback."""
 
 
-def _base_headers(headers):
-    version = pkg_resources.get_distribution("google-resumable-media").version
-    headers["User-Agent"] = "gcloud-python/{}-resumable-media".format(version)
-    headers["X-Goog-Api-Client"] = "gcloud-python/{}-resumable-media".format(version)
-    return headers
-
-
 def header_required(response, name, get_headers, callback=do_nothing):
     """Checks that a specific header is in a headers dictionary.
 
