@@ -604,11 +604,11 @@ transmitted in chunks until completion:
    upload._chunk_size = 4
    # Make three fake responses.
    fake_response0 = requests.Response()
-   fake_response0.status_code = resumable_media.PERMANENT_REDIRECT
+   fake_response0.status_code = http.client.PERMANENT_REDIRECT
    fake_response0.headers['range'] = 'bytes=0-3'
 
    fake_response1 = requests.Response()
-   fake_response1.status_code = resumable_media.PERMANENT_REDIRECT
+   fake_response1.status_code = http.client.PERMANENT_REDIRECT
    fake_response1.headers['range'] = 'bytes=0-7'
 
    fake_response2 = requests.Response()
@@ -631,7 +631,7 @@ transmitted in chunks until completion:
 
    >>> response0 = upload.transmit_next_chunk(transport)
    >>> response0
-   <Response [308]>
+   <Response [HTTPStatus.PERMANENT_REDIRECT]>
    >>> upload.finished
    False
    >>> upload.bytes_uploaded == upload.chunk_size
@@ -639,7 +639,7 @@ transmitted in chunks until completion:
    >>>
    >>> response1 = upload.transmit_next_chunk(transport)
    >>> response1
-   <Response [308]>
+   <Response [HTTPStatus.PERMANENT_REDIRECT]>
    >>> upload.finished
    False
    >>> upload.bytes_uploaded == 2 * upload.chunk_size
