@@ -19,7 +19,7 @@ import io
 import os
 import urllib.parse
 
-import pytest
+import pytest  # type: ignore
 import mock
 
 from google.resumable_media import common
@@ -182,7 +182,7 @@ def transmit_chunks(
             )
         else:
             assert upload.bytes_uploaded == num_chunks * upload.chunk_size
-            assert response.status_code == resumable_media.PERMANENT_REDIRECT
+            assert response.status_code == http.client.PERMANENT_REDIRECT
 
     return num_chunks
 
@@ -427,7 +427,7 @@ def sabotage_and_recover(upload, stream, transport, chunk_size):
     upload._bytes_uploaded = 0  # Make ``bytes_uploaded`` wrong as well.
     # Recover the (artifically) invalid upload.
     response = upload.recover(transport)
-    assert response.status_code == resumable_media.PERMANENT_REDIRECT
+    assert response.status_code == http.client.PERMANENT_REDIRECT
     assert not upload.invalid
     assert upload.bytes_uploaded == chunk_size
     assert stream.tell() == chunk_size
@@ -456,7 +456,7 @@ def _resumable_upload_recover_helper(
     check_initiate(response, upload, stream, authorized_transport, metadata)
     # Make the first request.
     response = upload.transmit_next_chunk(authorized_transport)
-    assert response.status_code == resumable_media.PERMANENT_REDIRECT
+    assert response.status_code == http.client.PERMANENT_REDIRECT
     # Call upload.recover().
     sabotage_and_recover(upload, stream, authorized_transport, chunk_size)
     # Now stream what remains.
@@ -508,7 +508,7 @@ class TestResumableUploadUnknownSize(object):
 
         assert not upload.finished
         assert upload.bytes_uploaded == end_byte + 1
-        assert response.status_code == resumable_media.PERMANENT_REDIRECT
+        assert response.status_code == http.client.PERMANENT_REDIRECT
         assert response.content == b""
 
         self._check_range_sent(response, start_byte, end_byte, "*")
