@@ -22,7 +22,6 @@ import pytest  # type: ignore
 from google.resumable_media import _helpers
 from google.resumable_media import _upload
 from google.resumable_media import common
-from google.resumable_media._helpers import _base_headers
 
 
 URL_PREFIX = "https://www.googleapis.com/upload/storage/v1/b/{BUCKET}/o"
@@ -39,7 +38,7 @@ class TestUploadBase(object):
     def test_constructor_defaults(self):
         upload = _upload.UploadBase(SIMPLE_URL)
         assert upload.upload_url == SIMPLE_URL
-        assert upload._headers == _base_headers({})
+        assert upload._headers == {}
         assert not upload._finished
         _check_retry_strategy(upload)
 
@@ -47,7 +46,7 @@ class TestUploadBase(object):
         headers = {"spin": "doctors"}
         upload = _upload.UploadBase(SIMPLE_URL, headers=headers)
         assert upload.upload_url == SIMPLE_URL
-        assert upload._headers == _base_headers(headers)
+        assert upload._headers is headers
         assert not upload._finished
         _check_retry_strategy(upload)
 
@@ -140,7 +139,7 @@ class TestSimpleUpload(object):
         assert method == "POST"
         assert url == SIMPLE_URL
         assert payload == data
-        assert headers == _base_headers({"content-type": content_type})
+        assert headers == {"content-type": content_type}
 
     def test__prepare_request_with_headers(self):
         headers = {"x-goog-cheetos": "spicy"}
@@ -152,8 +151,9 @@ class TestSimpleUpload(object):
         assert method == "POST"
         assert url == SIMPLE_URL
         assert payload == data
+        assert new_headers is headers
         expected = {"content-type": content_type, "x-goog-cheetos": "spicy"}
-        assert new_headers == _base_headers(expected)
+        assert headers == expected
 
     def test_transmit(self):
         upload = _upload.SimpleUpload(SIMPLE_URL)
@@ -167,7 +167,7 @@ class TestMultipartUpload(object):
     def test_constructor_defaults(self):
         upload = _upload.MultipartUpload(MULTIPART_URL)
         assert upload.upload_url == MULTIPART_URL
-        assert upload._headers == _base_headers({})
+        assert upload._headers == {}
         assert upload._checksum_type is None
         assert not upload._finished
         _check_retry_strategy(upload)
@@ -176,7 +176,7 @@ class TestMultipartUpload(object):
         headers = {"spin": "doctors"}
         upload = _upload.MultipartUpload(MULTIPART_URL, headers=headers, checksum="md5")
         assert upload.upload_url == MULTIPART_URL
-        assert upload._headers == _base_headers(headers)
+        assert upload._headers is headers
         assert upload._checksum_type == "md5"
         assert not upload._finished
         _check_retry_strategy(upload)
@@ -255,19 +255,18 @@ class TestMultipartUpload(object):
 
     def test__prepare_request(self):
         headers, multipart_type = self._prepare_request_helper()
-        assert headers == _base_headers({"content-type": multipart_type})
+        assert headers == {"content-type": multipart_type}
 
     def test__prepare_request_with_headers(self):
         headers = {"best": "shirt", "worst": "hat"}
         new_headers, multipart_type = self._prepare_request_helper(headers=headers)
-        expected_headers = _base_headers(
-            {
-                "best": "shirt",
-                "content-type": multipart_type,
-                "worst": "hat",
-            }
-        )
-        assert new_headers == expected_headers
+        assert new_headers is headers
+        expected_headers = {
+            "best": "shirt",
+            "content-type": multipart_type,
+            "worst": "hat",
+        }
+        assert expected_headers == headers
 
     @pytest.mark.parametrize("checksum", ["md5", "crc32c"])
     def test__prepare_request_with_checksum(self, checksum):
@@ -278,11 +277,9 @@ class TestMultipartUpload(object):
         headers, multipart_type = self._prepare_request_helper(
             checksum=checksum, expected_checksum=checksums[checksum]
         )
-        assert headers == _base_headers(
-            {
-                "content-type": multipart_type,
-            }
-        )
+        assert headers == {
+            "content-type": multipart_type,
+        }
 
     @pytest.mark.parametrize("checksum", ["md5", "crc32c"])
     def test__prepare_request_with_checksum_overwrite(self, checksum):
@@ -295,11 +292,9 @@ class TestMultipartUpload(object):
             expected_checksum=checksums[checksum],
             test_overwrite=True,
         )
-        assert headers == _base_headers(
-            {
-                "content-type": multipart_type,
-            }
-        )
+        assert headers == {
+            "content-type": multipart_type,
+        }
 
     def test_transmit(self):
         upload = _upload.MultipartUpload(MULTIPART_URL)
@@ -314,7 +309,7 @@ class TestResumableUpload(object):
         chunk_size = ONE_MB
         upload = _upload.ResumableUpload(RESUMABLE_URL, chunk_size)
         assert upload.upload_url == RESUMABLE_URL
-        assert upload._headers == _base_headers({})
+        assert upload._headers == {}
         assert not upload._finished
         _check_retry_strategy(upload)
         assert upload._chunk_size == chunk_size
@@ -440,7 +435,7 @@ class TestResumableUpload(object):
             "x-upload-content-length": "{:d}".format(len(data)),
             "x-upload-content-type": BASIC_CONTENT,
         }
-        assert headers == _base_headers(expected_headers)
+        assert headers == expected_headers
 
     def test_prepare_initiate_request_with_signed_url(self):
         signed_urls = [
@@ -455,7 +450,7 @@ class TestResumableUpload(object):
                 "content-type": BASIC_CONTENT,
                 "x-upload-content-length": "{:d}".format(len(data)),
             }
-            assert headers == _base_headers(expected_headers)
+            assert headers == expected_headers
 
     def test__prepare_initiate_request_with_headers(self):
         headers = {"caviar": "beluga", "top": "quark"}
@@ -469,7 +464,7 @@ class TestResumableUpload(object):
             "x-upload-content-length": "{:d}".format(len(data)),
             "x-upload-content-type": BASIC_CONTENT,
         }
-        assert new_headers == _base_headers(expected_headers)
+        assert new_headers == expected_headers
 
     def test__prepare_initiate_request_known_size(self):
         total_bytes = 25
@@ -480,7 +475,7 @@ class TestResumableUpload(object):
             "x-upload-content-length": "{:d}".format(total_bytes),
             "x-upload-content-type": BASIC_CONTENT,
         }
-        assert headers == _base_headers(expected_headers)
+        assert headers == expected_headers
 
     def test__prepare_initiate_request_unknown_size(self):
         _, headers = self._prepare_initiate_request_helper(stream_final=False)
@@ -488,7 +483,7 @@ class TestResumableUpload(object):
             "content-type": "application/json; charset=UTF-8",
             "x-upload-content-type": BASIC_CONTENT,
         }
-        assert headers == _base_headers(expected_headers)
+        assert headers == expected_headers
 
     def test__prepare_initiate_request_already_initiated(self):
         upload = _upload.ResumableUpload(RESUMABLE_URL, ONE_MB)
@@ -965,7 +960,7 @@ class TestResumableUpload(object):
         assert payload is None
         assert headers == {"content-range": "bytes */*"}
         # Make sure headers are untouched.
-        assert upload._headers == _base_headers({})
+        assert upload._headers == {}
 
     def test__prepare_recover_request_with_headers(self):
         headers = {"lake": "ocean"}
@@ -980,7 +975,7 @@ class TestResumableUpload(object):
         # Make sure the ``_headers`` are not incorporated.
         assert "lake" not in new_headers
         # Make sure headers are untouched.
-        assert upload._headers == _base_headers({"lake": "ocean"})
+        assert upload._headers == {"lake": "ocean"}
 
     def test__process_recover_response_bad_status(self):
         upload = _upload.ResumableUpload(RESUMABLE_URL, ONE_MB)
